from course import CourseCollection
from resource import ResourceInstance, ResourceCollection
from school import SchoolCollection
from teacher import TeacherCollection
from section import SectionCollection
from student import StudentCollection
from term import TermCollection
from attendance import AttendanceCollection
from course_grade import CourseGradeCollection

class Organization(ResourceInstance):
  subresources = [CourseCollection, SchoolCollection, SectionCollection, StudentCollection, TeacherCollection, TermCollection, AttendanceCollection, CourseGradeCollection]


class OrganizationCollection(ResourceCollection):
  uri_resource_name = "org"
  collection_name = "organizations"
  instance_class = Organization
